/* Copyright (c) 2015-present, salesforce.com, inc. All rights reserved
  Licensed under BSD 3-Clause - see LICENSE.txt or git.io/sfdc-license */
import mdx from './input-radio-group.mdx';

export default {
  title: 'Product Subsystem/Components/Input Radio Group',
  parameters: {
    docs: {
      page: mdx,
    },
  },
  argTypes: {
    legend: {
      control: {
        type: 'text',
      },
      table: {
        category: 'attributes',
      },
    },
    name: {
      control: {
        type: 'text',
      },
      table: {
        category: 'attributes',
      },
    },
    orientation: {
      control: {
        type: 'radio',
      },
      options: ['vertical', 'horizontal'],
      table: {
        category: 'attributes',
      },
    },
    direction: {
      control: {
        type: 'radio',
      },
      options: ['ltr', 'rtl'],
      table: {
        category: 'attributes',
      },
    },
    'selected-option': {
      control: {
        type: 'text',
      },
      table: {
        category: 'attributes',
      },
    },
    'Help Text': {
      control: {
        type: 'text',
      },
      table: {
        category: 'slots',
      },
    },
    disabled: {
      control: {
        type: 'boolean',
      },
      table: {
        category: 'attributes',
      },
    },
    required: {
      control: {
        type: 'boolean',
      },
      table: {
        category: 'attributes',
      },
    },
    invalid: {
      control: {
        type: 'boolean',
      },
      table: {
        category: 'attributes',
      },
    },
    variant: {
      control: {
        type: 'radio',
      },
      options: ['standard', 'label-hidden', 'label-inline', 'label-stacked'],
      table: {
        category: 'attributes',
      },
    },
  },
};

export const Base = (args) => `
<div dir="${args.direction}">
  <slds-input-radio-group
    class="slds-form-element"
    ${args.legend ? `legend="${args.legend}"` : ''}
    ${args.name ? `name="${args.name}"` : ''}
    ${args.disabled ? 'disabled' : ''}
    ${args.required ? 'required' : ''}
    ${args.invalid ? 'aria-invalid="true"' : ''}
    ${args['selected-option'] ? `selected-option=${args['selected-option']}` : ''}
    ${args.orientation ? `orientation="${args.orientation}"` : ''}
    ${args.variant ? `variant="${args.variant}"` : ''}
    >
    ${args['Help Text'] && `<div slot="help-text">${args['Help Text']}</div>`}
  </slds-input-radio-group>
  <div id="output" type-style="display-8"></div>
  </div>
  <script>
    var radioGroup = document.querySelector("slds-input-radio-group");
    radioGroup.options = [{label:'Spring', value:'spring'}, {label:'Summer', value:'summer'}, {label:'Fall', value:'fall'}, {label:'Winter', value:'winter'}]
    ${args['selected-option'] ? '' : "radioGroup.selectedOption = 'summer';"}
    radioGroup.shadowRoot.querySelector("fieldset").addEventListener('change', event => {
      const para = document.createElement("p");
      para.innerHTML = event.target.value + ' <span>is selected!</span>';
      document.querySelector('#output').appendChild(para);
    });
  </script>
  `;

Base.args = {
  orientation: 'vertical',
  direction: 'ltr',
  legend: 'Your favorite season of the year?',
  name: 'season',
  invalid: false,
  required: true,
  disabled: false,
  variant: 'standard',
};

const StylingHookStyles = (args) => `
  --slds-c-inputradiogroup-legend-font-size: ${args['Legend Size']}px;
  --slds-c-inputradiogroup-legend-font-weight: ${args['Legend Weight']};
  --slds-c-inputradiogroup-legend-color: ${args['Legend Color']};
  --slds-c-inputradiogroup-label-font-size: ${args['Radio Label Size']}px;
  --slds-c-inputradiogroup-label-color: ${args['Radio Label Color']};

  --slds-c-inputradiogroup-options-spacing-gap: ${args['Radio Spacing']}px;
  --slds-c-inputradiogroup-legend-spacing-block-end: ${args['Legend Spacing']}px;
  --slds-c-inputradiogroup-label-spacing-inline-start: ${args['Radio Label Spacing']}px;

  --slds-c-inputradiogroup-indicator-shadow-focus: 0 0 5px 0 ${args['Radio Border Color Focus']};

  ${args['Radio Size'] && `--slds-c-inputradiogroup-indicator-sizing: ${args['Radio Size']}px;`}
  ${args['Radio Mark Size'] && `--slds-c-inputradiogroup-mark-sizing: ${args['Radio Mark Size']}px`};

  --slds-c-inputradiogroup-indicator-color-border: ${args['Radio Border Color']};
  --slds-c-inputradiogroup-indicator-color-border-hover: ${args['Radio Border Color Hover']};
  --slds-c-inputradiogroup-indicator-color-border-focus: ${args['Radio Border Color Focus']};
  --slds-c-inputradiogroup-indicator-color-background: ${args['Radio Background Color']};
  --slds-c-inputradiogroup-indicator-color-background-hover: ${args['Radio Background Color Hover']};
  --slds-c-inputradiogroup-indicator-color-background-focus: ${args['Radio Background Color Focus']};

  --slds-c-inputradiogroup-indicator-color-border-checked: ${args['Radio Border Color']};
  --slds-c-inputradiogroup-indicator-color-border-checked-hover: ${args['Radio Border Color Hover']};
  --slds-c-inputradiogroup-indicator-color-border-checked-focus: ${args['Radio Border Color Focus']};
  --slds-c-inputradiogroup-indicator-color-background-checked: ${args['Radio Background Color']};
  --slds-c-inputradiogroup-indicator-color-background-checked-hover: ${args['Radio Background Color Hover']};
  --slds-c-inputradiogroup-indicator-color-background-checked-focus: ${args['Radio Background Color Focus']};

  --slds-c-inputradiogroup-indicator-color-border-disabled: ${args['Radio Border Color Disabled']};
  --slds-c-inputradiogroup-indicator-color-background-disabled: ${args['Radio Background Color Disabled']};

  --slds-c-inputradiogroup-indicator-color-background-invalid: ${args['Radio Background Color Invalid']};
  --slds-c-inputradiogroup-indicator-color-border-invalid: ${args['Radio Border Color Invalid']};
  --slds-c-inputradiogroup-indicator-sizing-border: ${args['Indicator Border Width']}px;
  --slds-c-inputradiogroup-indicator-sizing-border-invalid: ${args['Indicator Border Width Invalid']}px;

  --slds-c-inputradiogroup-mark-color-background: ${args['Radio Mark Color']};
  --slds-c-inputradiogroup-mark-color-background-hover: ${args['Radio Mark Color Hover']};
  --slds-c-inputradiogroup-mark-color-background-focus: ${args['Radio Mark Color Focus']};
  --slds-c-inputradiogroup-mark-color-background-disabled: ${args['Radio Mark Color Disabled']};
  --slds-c-inputradiogroup-mark-color-background-invalid: ${args['Radio Mark Color Invalid']};
`;

const StylingHookTemplate = (args) => `
  <div style="${StylingHookStyles(args)}" dir="${args.direction}">
    <slds-input-radio-group
      class="slds-form-element"
      ${args.legend ? `legend="${args.legend}"` : ''}
      ${args.name ? `name="${args.name}"` : ''}
      ${args.disabled ? 'disabled' : ''}
      ${args.required ? 'required' : ''}
      ${args.invalid ? 'aria-invalid="true"' : ''}
      ${args['selected-option'] ? `selected-option=${args['selected-option']}` : ''}
      ${args.orientation ? `orientation="${args.orientation}"` : ''}
      ${args.variant ? `variant="${args.variant}"` : ''}
      >
      ${args['Help Text'] && `<div style="color: red;" slot="help-text">${args['Help Text']}</div>`}
    </slds-input-radio-group>
  <div id="output" type-style="display-8"></div>
  </div>
  <script>
    var radioGroup = document.querySelector("slds-input-radio-group");
    radioGroup.options = [{label:'Spring', value:'spring'}, {label:'Summer', value:'summer'}, {label:'Fall', value:'fall'}, {label:'Winter', value:'winter'}]
    ${args['selected-option'] ? '' : "radioGroup.selectedOption = 'summer';"}
    radioGroup.shadowRoot.querySelector("fieldset").addEventListener('change', event => {
      const para = document.createElement("p");
      para.innerHTML = event.target.value + ' <span>is selected!</span>';
      document.querySelector('#output').appendChild(para);
    });
  </script>
</div>`;

export const StylingHooks = StylingHookTemplate.bind({});

const StylingHooksDemo = {
  'Legend Size': '20',
  'Legend Weight': 700,
  'Legend Spacing': 12,

  'Radio Label Size': 16,
  'Radio Label Spacing': 12,
  'Radio Spacing': 8,
  'Radio Size': 20,
  'Radio Mark Size': 10,

  'Indicator Border Width': 2,
  'Indicator Border Width Invalid': 3,

  'Radio Label Color': 'sienna',
  'Legend Color': 'sienna',

  'Radio Background Color': 'peachpuff',
  'Radio Border Color': 'sienna',
  'Radio Mark Color': 'sienna',

  'Radio Background Color Invalid': 'pink',
  'Radio Border Color Invalid': 'hotpink',
  'Radio Mark Color Invalid': 'hotpink',

  'Radio Background Color Disabled': 'lightgrey',
  'Radio Border Color Disabled': 'grey',
  'Radio Mark Color Disabled': 'grey',

  'Radio Background Color Hover': 'lightgreen',
  'Radio Border Color Hover': 'green',
  'Radio Mark Color Hover': 'green',

  'Radio Background Color Focus': 'plum',
  'Radio Border Color Focus': 'purple',
  'Radio Mark Color Focus': 'purple',
};

StylingHooks.args = {
  ...StylingHooksDemo,
  legend: 'Your favorite season of the year?',
  name: 'season',
  'Help Text': '',
  invalid: false,
  disabled: false,
  variant: 'standard',
};

StylingHooks.argTypes = {
  invalid: {
    control: {
      type: 'boolean',
    },
    table: {
      category: 'Radio State',
    },
  },
  disabled: {
    control: {
      type: 'boolean',
    },
    table: {
      category: 'Radio State',
    },
  },
  variant: {
    control: {
      type: 'radio',
    },
    options: ['standard', 'label-hidden', 'label-inline', 'label-stacked'],
    table: {
      category: 'attributes',
    },
  },
  'Radio Label Size': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Radio Label Spacing': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Radio Spacing': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Radio Size': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Radio Mark Size': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Legend Size': {
    control: {
      type: 'text',
    },
    table: {
      category: 'Legend Styling Hooks',
    },
  },
  'Legend Weight': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Legend Styling Hooks',
    },
  },
  'Legend Spacing': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Legend Styling Hooks',
    },
  },
  'Legend Color': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Legend Styling Hooks',
    },
  },
  'Radio Label Color': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Radio Styling Hooks',
    },
  },
  'Indicator Border Width': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Indicator Border Width Invalid': {
    control: {
      type: 'number',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Background Color': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Border Color': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Mark Color': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Background Color Hover': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Border Color Hover': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Mark Color Hover': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Background Color Focus': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Border Color Focus': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Mark Color Focus': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Background Color Invalid': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Border Color Invalid': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Mark Color Invalid': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Background Color Disabled': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Border Color Disabled': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
  'Radio Mark Color Disabled': {
    control: {
      type: 'color',
    },
    table: {
      category: 'Indicator Styling Hooks',
    },
  },
};
